@@ -13,7 +13,7 @@
 ##############################################################################
 """Implementation of Key Management Facility
 
-$Id: facility.py 90842 2008-09-04 21:00:30Z mgedmin $
+$Id: facility.py 102315 2009-07-27 02:00:33Z srichter $
 """
 from __future__ import absolute_import
 __docformat__ = "reStructuredText"
@@ -26,7 +26,7 @@ import zope.interface
 import zope.location
 from z3c.rest import client
 from zope.annotation.interfaces import IAttributeAnnotatable
-from zope.app.container import btree
+from zope.container import btree
 from zope.dublincore import property
 from zope.schema.fieldproperty import FieldProperty
 from keas.kmi import interfaces
